==> free-sa-1.3.4.tar.gz: free-sa-1.3.4/src/reports/r_email.c <==
#include "global.h"


size_t maxvname = 0L;


#define LENNO		4L
#define LENCONN		7L
#define LENBYTES	15L


void ReportEmail(void) {
    FILE *ER;
    short int i;
    int nolen = (int)SAmax(LENNO, strlen(loc->No)), 
	userlen = (int)SAmax(maxvname, strlen(loc->User)), 
	connlen = (int)SAmax(LENCONN, strlen(loc->Connections)), 
	byteslen = (int)SAmax(LENBYTES, strlen(loc->Bytes));
    char stext[FILENAMESIZE * 2L], tfname[FILENAMESIZE];
    
    /* ER: open */
    if (cfg.ER[0] == '-' && cfg.ER[1] == '\0') ER = stdout;
    else {
	SAsnprintf(tfname, sizeof(tfname), "%s/%s", cfg.TmpDir, icfg.ERname);
	ER = SAfopenI("w", tfname);
    }
    
    /* ER: header */
    SAfprintf(ER, "\
%*s p s p s c p d\n\
%*s %-*s %*s %*s a a d d c s l\n\
%*s f f n n t t d\n", 
	    nolen + userlen + connlen + byteslen + 3, " ", 
    	    nolen, loc->No, userlen, loc->User, connlen, loc->Connections, byteslen, loc->Bytes,
	    nolen + userlen + connlen + byteslen + 3, " ");

    /* ER: separator */
    for (i = 0; i < nolen + userlen + connlen + byteslen + 7 + 4 + 6; i++) SAfwrite1("=", 1L, ER);
    SAfwrite1("\n", 1L, ER);
    
    /* ER: body */
    for (i = 0; i < icfg.ueCount; i++)
	if (Users[i].count)
	    SAfprintf(ER, "%*hd %-*s %'*d %*s %c %c %c %c %c %c %c\n", 
	    nolen, i + 1,
	    userlen, Users[i].vname, 
	    connlen, Users[i].count, 
	    byteslen, icfg.SAB(Users[i].Bytes),
	    (Users[i].TTcount[PAF]) ? '1' : ' ',
	    (Users[i].TTcount[SAF]) ? '2' : ' ',
	    (Users[i].TTcount[PDN]) ? '3' : ' ',
	    (Users[i].TTcount[SDN]) ? '4' : ' ',
	    (Users[i].TTcount[CCT]) ? '5' : ' ',
	    (Users[i].TTcount[PST]) ? '6' : ' ',
	    (Users[i].TTcount[DLD]) ? '7' : ' ');

    /* ER: separator */
    for (i = 0; i < nolen + userlen + connlen + byteslen + 7 + 4 + 6; i++) SAfwrite1("=", 1L, ER);
    SAfwrite1("\n", 1L, ER);
    
    /* ER: total and average */
    SAfprintf(ER, "%*s %-*s %'*d %*s\n", nolen, " ", userlen, loc->TOTAL, connlen, ccCount, byteslen, icfg.SAB(ccBytes));
    SAfprintf(ER, "%*s %-*s %'*d %*s\n", nolen, " ", userlen, loc->AVERAGE, connlen, ccCount / ccueCount, byteslen, icfg.SAB(ccBytes / ccueCount));

    /* ER: close and mail */
    if (!(cfg.ER[0] == '-' && cfg.ER[1] == '\0')) {
	SAfclose(ER, icfg.ERname);
	SAsnprintf(stext, sizeof(stext), "%s -s \"[%s] %s %s\" %s < %s", CMDMAILX, PROGNAME, icfg.Period, cfg.Name, cfg.ER, tfname);
	SAsystem(CMDSH, CMDSH, "-c", stext, NULL);
	SAunlink(tfname);
    }
}

==> free-sa-1.4.3.tar.gz: free-sa-1.4.3/src/reports/r_email.c <==
#include "global.h"


size_t maxvname = 0L;


#define LENNO		4L
#define LENCONN		7L
#define LENBYTES	15L


void ReportEmail(void) {
    FILE *ER;
    short int i;
    int nolen = (int)SAmax(LENNO, strlen(loc->No)), 
	userlen = (int)SAmax(maxvname, strlen(loc->User)), 
	connlen = (int)SAmax(LENCONN, strlen(loc->Connections)), 
	byteslen = (int)SAmax(LENBYTES, strlen(loc->Bytes));
    char stext[FILENAMESIZE * 2L], tfname[FILENAMESIZE];
    
    /* ER: open */
    if (cfg.ER[0] == '-' && cfg.ER[1] == '\0') ER = stdout;
    else {
	SAsnprintf(tfname, sizeof(tfname), "%s/%s", cfg.TmpDir, icfg.ERname);
	ER = SAfopenI("w", tfname);
    }
    
    /* ER: header */
    SAfprintf(ER, "\
%*s p s p s c p d l\n\
%*s %-*s %*s %*s a a d d c s l c\n\
%*s f f n n t t d f\n", 
	    nolen + userlen + connlen + byteslen + 3, " ", 
    	    nolen, loc->No, userlen, loc->User, connlen, loc->Connections, byteslen, loc->Bytes,
	    nolen + userlen + connlen + byteslen + 3, " ");

    /* ER: separator */
    for (i = 0; i < nolen + userlen + connlen + byteslen + 8 + 4 + 7; i++) SAfwrite1("=", 1L, ER);
    SAfwrite1("\n", 1L, ER);
    
    /* ER: body */
    for (i = 0; i < icfg.ueCount; i++)
	if (Users[i].count)
	    SAfprintf(ER, "%*hd %-*s %'*d %*s %c %c %c %c %c %c %c %c\n", 
	    nolen, i + 1,
	    userlen, Users[i].vname, 
	    connlen, Users[i].count, 
	    byteslen, icfg.SAB(Users[i].Bytes),
	    (Users[i].TTcount[PAF]) ? '1' : ' ',
	    (Users[i].TTcount[SAF]) ? '2' : ' ',
	    (Users[i].TTcount[PDN]) ? '3' : ' ',
	    (Users[i].TTcount[SDN]) ? '4' : ' ',
	    (Users[i].TTcount[CCT]) ? '5' : ' ',
	    (Users[i].TTcount[PST]) ? '6' : ' ',
	    (Users[i].TTcount[DLD]) ? '7' : ' ',
	    (Users[i].TTcount[LCF]) ? '8' : ' ');

    /* ER: separator */
    for (i = 0; i < nolen + userlen + connlen + byteslen + 8 + 4 + 7; i++) SAfwrite1("=", 1L, ER);
    SAfwrite1("\n", 1L, ER);
    
    /* ER: total and average */
    SAfprintf(ER, "%*s %-*s %'*d %*s\n", nolen, " ", userlen, loc->TOTAL, connlen, ccCount, byteslen, icfg.SAB(ccBytes));
    SAfprintf(ER, "%*s %-*s %'*d %*s\n", nolen, " ", userlen, loc->AVERAGE, connlen, ccCount / ccueCount, byteslen, icfg.SAB(ccBytes / ccueCount));

    /* ER: close and mail */
    if (!(cfg.ER[0] == '-' && cfg.ER[1] == '\0')) {
	SAfclose(ER, icfg.ERname);
	SAsnprintf(stext, sizeof(stext), "%s -s \"[%s] %s %s\" %s < %s", CMDMAILX, PROGNAME, icfg.Period, cfg.Name, cfg.ER, tfname);
	SAsystem(CMDSH, CMDSH, "-c", stext, NULL);
	SAunlink(tfname);
    }
}
